==> grizzly-1.0.0.tar.gz: lib/src/double/double_iterable.dart <==
import 'dart:math' as math;

import 'package:grizzly/src/utils/comap.dart';

extension DoubleExt on double {
  double toPrecision(int places) {
    num pld = math.pow(10,places);
    return (this * pld).truncateToDouble()/pld;
  }
}

extension DoubleIterableExt on Iterable<double> {
  Iterable<double> plus(/* Iterable<num> | num */ other) {
    if (other is num) {
      return map((e) => e + other);
    } else if (other is Iterable<num>) {
      return comap<double, num?, num?>(
          this, other, (a, b) => (a ?? 0).toDouble() + (b ?? 0));
    }

    throw UnsupportedError('only num and Iterable<num> are supported');
  }

  Iterable<double> operator -(/* Iterable<num> | num */ other) {
    if (other is num) {
      return map((e) => e - other);
    } else if (other is Iterable<num>) {
      return comap<double, num?, num?>(
          this, other, (a, b) => (a ?? 0).toDouble() - (b ?? 0));
    }

    throw UnsupportedError('only num and Iterable<num> are supported');
  }

  Iterable<double> operator *(/* Iterable<num> | num */ other) {
    if (other is num) {
      return map((e) => e * other);
    } else if (other is Iterable<num>) {
      return comap<double, num?, num?>(
          this, other, (a, b) => (a ?? 0).toDouble() * (b ?? 0));
    }

    throw UnsupportedError('only num and Iterable<num> are supported');
  }

  Iterable<double> operator /(/* Iterable<num> | num */ other) {
    if (other is num) {
      return map((e) => e / other);
    } else if (other is Iterable<num>) {
      return comap<double, num?, num?>(
          this, other, (a, b) => (a ?? 0).toDouble() / (b ?? 0));
    }

    throw UnsupportedError('only num and Iterable<num> are supported');
  }

  Iterable<int> operator ~/(/* Iterable<num> | num */ other) {
    if (other is num) {
      return map((e) => e ~/ other);
    } else if (other is Iterable<num>) {
      return comap<int, num?, num?>(
          this, other, (a, b) => (a ?? 0) ~/ (b ?? 0));
    }

    throw UnsupportedError('only num | Iterable<num> are supported');
  }

  double dot([Iterable<num?>? other]) => cofold<double, double, num?>(
      0, this, other ?? this, (value, double? a, num? b) => value + a! * (b ?? 0));

  bool isClose(Iterable<num> v, {double tol = 1e-8}) {
    if (length != v.length) return false;
    for (int i = 0; i < length; i++) {
      if ((elementAt(i) - v.elementAt(i)).abs() > tol) return false;
    }
    return true;
  }

  bool isCloseScalar(num v, {double tol = 1e-8}) {
    for (int i = 0; i < length; i++) {
      if ((elementAt(i) - v).abs() > tol) return false;
    }
    return true;
  }
}

==> grizzly-1.0.4.tar.gz: lib/src/double/double_iterable.dart <==
import 'dart:math' as math;

import 'package:grizzly/src/utils/comap.dart';

extension DoubleExt on double {
  double toPrecision(int places) {
    num pld = math.pow(10, places);
    return (this * pld).truncateToDouble() / pld;
  }
}

extension DoubleIterableExt on Iterable<double> {
  Iterable<double> plus(/* Iterable<num> | num */ other) {
    if (other is num) {
      return map((e) => e + other);
    } else if (other is Iterable<num>) {
      return comap<double, num?, num?>(
          this, other, (a, b) => (a ?? 0).toDouble() + (b ?? 0));
    }

    throw UnsupportedError('only num and Iterable<num> are supported');
  }

  Iterable<double> operator -(/* Iterable<num> | num */ other) {
    if (other is num) {
      return map((e) => e - other);
    } else if (other is Iterable<num>) {
      return comap<double, num?, num?>(
          this, other, (a, b) => (a ?? 0).toDouble() - (b ?? 0));
    }

    throw UnsupportedError('only num and Iterable<num> are supported');
  }

  Iterable<double> operator *(/* Iterable<num> | num */ other) {
    if (other is num) {
      return map((e) => e * other);
    } else if (other is Iterable<num>) {
      return comap<double, num?, num?>(
          this, other, (a, b) => (a ?? 0).toDouble() * (b ?? 0));
    }

    throw UnsupportedError('only num and Iterable<num> are supported');
  }

  Iterable<double> operator /(/* Iterable<num> | num */ other) {
    if (other is num) {
      return map((e) => e / other);
    } else if (other is Iterable<num>) {
      return comap<double, num?, num?>(
          this, other, (a, b) => (a ?? 0).toDouble() / (b ?? 0));
    }

    throw UnsupportedError('only num and Iterable<num> are supported');
  }

  Iterable<int> operator ~/(/* Iterable<num> | num */ other) {
    if (other is num) {
      return map((e) => e ~/ other);
    } else if (other is Iterable<num>) {
      return comap<int, num?, num?>(
          this, other, (a, b) => (a ?? 0) ~/ (b ?? 0));
    }

    throw UnsupportedError('only num | Iterable<num> are supported');
  }

  double dot([Iterable<num?>? other]) => cofold<double, double, num?>(0, this,
      other ?? this, (value, double? a, num? b) => value + a! * (b ?? 0));

  bool isEqual(Iterable<num> v, {double eps = 1e-8}) {
    if (length != v.length) return false;
    final iter1 = iterator;
    final iter2 = v.iterator;
    while (iter1.moveNext() && iter2.moveNext()) {
      if ((iter1.current - iter2.current).abs() > eps) {
        return false;
      }
    }
    return true;
  }

  void assertEqual(Iterable<num> v, {double eps = 1e-8}) {
    if (length != v.length) {
      throw AssertionError('Length mismatch');
    }
    final iter1 = iterator;
    final iter2 = v.iterator;
    int i = 0;
    while (iter1.moveNext() && iter2.moveNext()) {
      final diff = (iter1.current - iter2.current).abs();
      if (diff > eps) {
        throw AssertionError('$i =>  ${iter1.current} != ${iter2.current}');
      }
      i++;
    }
  }

  bool isEqualScalar(num v, {double eps = 1e-8}) {
    for (final item in this) {
      if ((item - v).abs() > eps) return false;
    }
    return true;
  }
}
